==> genebot-1.1.23.tar.gz: genebot-1.1.23/docs/README.md <==
# Trading Bot Python - Documentation

## Overview

Welcome to the comprehensive documentation for the Trading Bot Python system. This documentation provides everything you need to understand, deploy, and operate the trading bot effectively.

## Documentation Structure

### 📚 Core Documentation

- **[API Reference](API_REFERENCE.md)** - Complete API documentation for all public interfaces
- **[Configuration Guide](CONFIGURATION.md)** - Comprehensive configuration reference
- **[Deployment Guide](DEPLOYMENT_GUIDE.md)** - Step-by-step deployment instructions
- **[User Guide](USER_GUIDE.md)** - Complete user manual for bot operation

### 🎯 Strategy Development

- **[Strategy Development Guide](STRATEGY_DEVELOPMENT_GUIDE.md)** - Learn to create custom trading strategies
- **[Advanced Strategies](ADVANCED_STRATEGIES.md)** - Advanced strategy patterns and techniques
- **[Anti-Greed Trading System](ANTI_GREED_TRADING_SYSTEM.md)** - Specialized risk management system

### 📋 Quick Start Guides

| Guide | Description | Audience |
|-------|-------------|----------|
| [5-Minute Setup](#5-minute-setup) | Get running quickly | Beginners |
| [Development Setup](#development-setup) | Development environment | Developers |
| [Production Deployment](#production-deployment) | Production deployment | DevOps |

## 5-Minute Setup

Get the trading bot running in 5 minutes:

```bash
# 1. Clone and setup
git clone https://github.com/your-org/trading-bot-python.git
cd trading-bot-python
python -m venv venv
source venv/bin/activate  # On Windows: venv\Scripts\activate
pip install -r requirements.txt

# 2. Configure
cp .env.example .env
# Edit .env with your API keys (use testnet keys!)

# 3. Run
python main.py --paper-trading
```

**Next Steps**: Read the [User Guide](USER_GUIDE.md) for detailed operation instructions.

## Development Setup

For developers wanting to contribute or customize:

```bash
# 1. Development installation
git clone https://github.com/your-org/trading-bot-python.git
cd trading-bot-python
python -m venv venv
source venv/bin/activate
pip install -r requirements.txt
pip install -e .

# 2. Setup development database
export DATABASE_URL="sqlite:///trading_bot_dev.db"
python scripts/init_db.py

# 3. Run tests
pytest

# 4. Start development server
python main.py --config examples/configuration_examples/development_config.yaml
```

**Next Steps**: Read the [Strategy Development Guide](STRATEGY_DEVELOPMENT_GUIDE.md) to create custom strategies.

## Production Deployment

For production deployments:

### Docker (Recommended)

```bash
# 1. Clone and configure
git clone https://github.com/your-org/trading-bot-python.git
cd trading-bot-python
cp .env.example .env
# Edit .env with production settings

# 2. Deploy with Docker Compose
docker-compose up -d

# 3. Monitor
docker-compose logs -f trading-bot
```

### Manual Deployment

```bash
# 1. Setup production environment
python -m venv venv
source venv/bin/activate
pip install -r requirements.txt

# 2. Configure production database
export DATABASE_URL="postgresql://user:pass@localhost:5432/trading_bot"
python scripts/init_db.py

# 3. Start with production config
python main.py --config examples/configuration_examples/production_config.yaml
```

**Next Steps**: Read the [Deployment Guide](DEPLOYMENT_GUIDE.md) for comprehensive deployment instructions.

## Key Features

### 🤖 Strategy Framework
- **Modular Design**: Easy to add custom strategies
- **Built-in Strategies**: Moving averages, RSI, multi-indicator
- **Backtesting**: Historical strategy testing
- **Live Trading**: Real-time strategy execution

### 🛡️ Risk Management
- **Position Sizing**: Automatic position size calculation
- **Stop Losses**: Configurable stop loss and trailing stops
- **Portfolio Limits**: Maximum position and drawdown limits
- **Circuit Breakers**: Automatic trading halts on excessive losses

### 📊 Monitoring & Alerts
- **Real-time Metrics**: Performance and system health monitoring
- **Grafana Dashboards**: Professional monitoring dashboards
- **Multi-channel Alerts**: Email, Slack, PagerDuty notifications
- **Health Checks**: Automated system health monitoring

### 🔧 Exchange Support
- **Multiple Exchanges**: Binance, Coinbase, Kraken support
- **Unified Interface**: Consistent API across exchanges
- **Rate Limiting**: Automatic rate limit handling
- **Failover**: Automatic exchange failover

## Architecture Overview

```
┌─────────────────┐    ┌─────────────────┐    ┌─────────────────┐
│   Strategies    │    │  Risk Manager   │    │   Exchanges     │
│                 │    │                 │    │                 │
│ • Moving Avg    │    │ • Position Size │    │ • Binance       │
│ • RSI           │    │ • Stop Loss     │    │ • Coinbase      │
│ • Multi-Ind     │    │ • Drawdown      │    │ • Kraken        │
└─────────────────┘    └─────────────────┘    └─────────────────┘
         │                       │                       │
         └───────────────────────┼───────────────────────┘
                                 │
                    ┌─────────────────┐
                    │  Trading Bot    │
                    │   Orchestrator  │
                    └─────────────────┘
                                 │
         ┌───────────────────────┼───────────────────────┐
         │                       │                       │
┌─────────────────┐    ┌─────────────────┐    ┌─────────────────┐
│  Data Collector │    │   Monitoring    │    │    Database     │
│                 │    │                 │    │                 │
│ • Market Data   │    │ • Metrics       │    │ • PostgreSQL    │
│ • Real-time     │    │ • Alerts        │    │ • SQLite        │
│ • Historical    │    │ • Health        │    │ • Backups       │
└─────────────────┘    └─────────────────┘    └─────────────────┘
```

## Example Strategies

### Moving Average Crossover
```python
from src.strategies.base_strategy import BaseStrategy

class MovingAverageStrategy(BaseStrategy):
    def analyze(self, data):
        short_ma = self.calculate_sma(data, self.short_period)
        long_ma = self.calculate_sma(data, self.long_period)
        
        if short_ma > long_ma:
            return self.create_signal("BUY", confidence=0.8)
        elif short_ma < long_ma:
            return self.create_signal("SELL", confidence=0.8)
        
        return self.create_signal("HOLD")
```

### RSI Mean Reversion
```python
class RSIStrategy(BaseStrategy):
    def analyze(self, data):
        rsi = self.calculate_rsi(data, self.rsi_period)
        
        if rsi < self.oversold_threshold:
            return self.create_signal("BUY", confidence=0.9)
        elif rsi > self.overbought_threshold:
            return self.create_signal("SELL", confidence=0.9)
        
        return self.create_signal("HOLD")
```

## Configuration Examples

### Development Configuration
```yaml
environment: "development"
exchanges:
  binance:
    sandbox: true  # Use testnet
risk_management:
  max_portfolio_risk: 0.001  # Very conservative
monitoring:
  alerting:
    enabled: false  # No alerts in dev
```

### Production Configuration
```yaml
environment: "production"
exchanges:
  binance:
    sandbox: false  # Live trading
risk_management:
  max_portfolio_risk: 0.01  # 1% risk per trade
monitoring:
  alerting:
    enabled: true
    channels: ["email", "slack"]
```

## Monitoring Dashboard

The bot includes comprehensive monitoring:

- **Portfolio Performance**: Real-time P&L tracking
- **Strategy Metrics**: Individual strategy performance
- **Risk Monitoring**: Drawdown and exposure tracking
- **System Health**: Exchange connectivity and error rates

Access the dashboard at `http://localhost:8000` after starting the bot.

## Safety Features

### Paper Trading Mode
Always test strategies in paper trading mode first:
```bash
python main.py --paper-trading
```

### Circuit Breakers
Automatic trading halts on:
- Daily loss exceeding threshold
- Maximum drawdown reached
- Excessive strategy errors
- Exchange connectivity issues

### Risk Controls
- **Position Sizing**: Automatic calculation based on risk tolerance
- **Stop Losses**: Configurable stop loss and trailing stops
- **Portfolio Limits**: Maximum positions and exposure limits
- **Correlation Limits**: Prevent over-concentration in correlated assets

## Getting Help

### Documentation
- **[User Guide](USER_GUIDE.md)**: Complete operation manual
- **[API Reference](API_REFERENCE.md)**: Technical API documentation
- **[Strategy Guide](STRATEGY_DEVELOPMENT_GUIDE.md)**: Custom strategy development

### Support Channels
- **GitHub Issues**: Bug reports and feature requests
- **Documentation**: Comprehensive guides and examples
- **Community**: Join discussions and share experiences

### Troubleshooting
Common issues and solutions:

1. **Bot won't start**: Check configuration and API keys
2. **No signals**: Verify strategy parameters and market data
3. **Connection errors**: Test exchange connectivity
4. **High memory usage**: Adjust data retention settings

See the [User Guide](USER_GUIDE.md) for detailed troubleshooting.

## Contributing

We welcome contributions! Please see:
- **Code Style**: Follow PEP 8 guidelines
- **Testing**: Add tests for new features
- **Documentation**: Update docs for changes
- **Issues**: Use GitHub issues for bugs and features

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Disclaimer

**Trading involves risk of loss. This software is provided as-is without warranty. Always test thoroughly before live trading and never risk more than you can afford to lose.**

---

## Quick Links

| Resource | Description |
|----------|-------------|
| [User Guide](USER_GUIDE.md) | Complete operation manual |
| [API Reference](API_REFERENCE.md) | Technical documentation |
| [Configuration](CONFIGURATION.md) | Configuration reference |
| [Deployment](DEPLOYMENT_GUIDE.md) | Deployment instructions |
| [Strategy Development](STRATEGY_DEVELOPMENT_GUIDE.md) | Custom strategies |
| [Examples](../examples/) | Code examples and templates |

**Happy Trading! 🚀**

==> genebot-1.1.39.tar.gz: genebot-1.1.39/docs/README.md <==
# Trading Bot Python - Documentation

## Overview

Welcome to the comprehensive documentation for the Trading Bot Python system. This documentation provides everything you need to understand, deploy, and operate the trading bot effectively.

## Documentation Structure

### 📚 Core Documentation

- **[API Reference](API_REFERENCE.md)** - Complete API documentation for all public interfaces
- **[Configuration Guide](CONFIGURATION.md)** - Comprehensive configuration reference
- **[Deployment Guide](DEPLOYMENT_GUIDE.md)** - Step-by-step deployment instructions
- **[User Guide](USER_GUIDE.md)** - Complete user manual for bot operation

### ⚙️ Configuration System (New in v1.1.28+)

GeneBot v1.1.28+ introduces a unified configuration system with intelligent discovery:

- **[Unified Configuration Guide](UNIFIED_CONFIGURATION_GUIDE.md)** - Complete guide to the new unified system
- **[Configuration Migration Guide](CONFIGURATION_MIGRATION_GUIDE.md)** - Step-by-step migration from hardcoded configurations
- **[Configuration Troubleshooting Guide](CONFIGURATION_TROUBLESHOOTING_GUIDE.md)** - Detailed troubleshooting help
- **[Comprehensive Configuration Guide](COMPREHENSIVE_CONFIGURATION_GUIDE.md)** - All configuration options and strategies

### 🎯 Strategy Development

- **[Strategy Development Guide](STRATEGY_DEVELOPMENT_GUIDE.md)** - Learn to create custom trading strategies
- **[Advanced Strategies](ADVANCED_STRATEGIES.md)** - Advanced strategy patterns and techniques
- **[Anti-Greed Trading System](ANTI_GREED_TRADING_SYSTEM.md)** - Specialized risk management system

### 📋 Quick Start Guides

| Guide | Description | Audience |
|-------|-------------|----------|
| [5-Minute Setup](#5-minute-setup) | Get running quickly | Beginners |
| [Development Setup](#development-setup) | Development environment | Developers |
| [Production Deployment](#production-deployment) | Production deployment | DevOps |

## 5-Minute Setup

Get the trading bot running in 5 minutes:

```bash
# 1. Clone and setup
git clone https://github.com/your-org/trading-bot-python.git
cd trading-bot-python
python -m venv venv
source venv/bin/activate  # On Windows: venv\Scripts\activate
pip install -r requirements.txt

# 2. Initialize configuration (new unified system)
genebot init-config
# Edit .env with your API keys (use testnet keys!)

# 3. Verify configuration
genebot config-status

# 4. Run (automatically uses discovered configuration)
genebot start --paper-trading
```

**Next Steps**: Read the [User Guide](USER_GUIDE.md) for detailed operation instructions.

## Development Setup

For developers wanting to contribute or customize:

```bash
# 1. Development installation
git clone https://github.com/your-org/trading-bot-python.git
cd trading-bot-python
python -m venv venv
source venv/bin/activate
pip install -r requirements.txt
pip install -e .

# 2. Setup development database
export DATABASE_URL="sqlite:///trading_bot_dev.db"
python scripts/init_db.py

# 3. Run tests
pytest

# 4. Start development server
python main.py --config examples/configuration_examples/development_config.yaml
```

**Next Steps**: Read the [Strategy Development Guide](STRATEGY_DEVELOPMENT_GUIDE.md) to create custom strategies.

## Production Deployment

For production deployments:

### Docker (Recommended)

```bash
# 1. Clone and configure
git clone https://github.com/your-org/trading-bot-python.git
cd trading-bot-python
cp .env.example .env
# Edit .env with production settings

# 2. Deploy with Docker Compose
docker-compose up -d

# 3. Monitor
docker-compose logs -f trading-bot
```

### Manual Deployment

```bash
# 1. Setup production environment
python -m venv venv
source venv/bin/activate
pip install -r requirements.txt

# 2. Configure production database
export DATABASE_URL="postgresql://user:pass@localhost:5432/trading_bot"
python scripts/init_db.py

# 3. Start with production config
python main.py --config examples/configuration_examples/production_config.yaml
```

**Next Steps**: Read the [Deployment Guide](DEPLOYMENT_GUIDE.md) for comprehensive deployment instructions.

## Key Features

### 🤖 Strategy Framework
- **Modular Design**: Easy to add custom strategies
- **Built-in Strategies**: Moving averages, RSI, multi-indicator
- **Backtesting**: Historical strategy testing
- **Live Trading**: Real-time strategy execution

### 🛡️ Risk Management
- **Position Sizing**: Automatic position size calculation
- **Stop Losses**: Configurable stop loss and trailing stops
- **Portfolio Limits**: Maximum position and drawdown limits
- **Circuit Breakers**: Automatic trading halts on excessive losses

### 📊 Monitoring & Alerts
- **Real-time Metrics**: Performance and system health monitoring
- **Grafana Dashboards**: Professional monitoring dashboards
- **Multi-channel Alerts**: Email, Slack, PagerDuty notifications
- **Health Checks**: Automated system health monitoring

### 🔧 Exchange Support
- **Multiple Exchanges**: Binance, Coinbase, Kraken support
- **Unified Interface**: Consistent API across exchanges
- **Rate Limiting**: Automatic rate limit handling
- **Failover**: Automatic exchange failover

## Architecture Overview

```
┌─────────────────┐    ┌─────────────────┐    ┌─────────────────┐
│   Strategies    │    │  Risk Manager   │    │   Exchanges     │
│                 │    │                 │    │                 │
│ • Moving Avg    │    │ • Position Size │    │ • Binance       │
│ • RSI           │    │ • Stop Loss     │    │ • Coinbase      │
│ • Multi-Ind     │    │ • Drawdown      │    │ • Kraken        │
└─────────────────┘    └─────────────────┘    └─────────────────┘
         │                       │                       │
         └───────────────────────┼───────────────────────┘
                                 │
                    ┌─────────────────┐
                    │  Trading Bot    │
                    │   Orchestrator  │
                    └─────────────────┘
                                 │
         ┌───────────────────────┼───────────────────────┐
         │                       │                       │
┌─────────────────┐    ┌─────────────────┐    ┌─────────────────┐
│  Data Collector │    │   Monitoring    │    │    Database     │
│                 │    │                 │    │                 │
│ • Market Data   │    │ • Metrics       │    │ • PostgreSQL    │
│ • Real-time     │    │ • Alerts        │    │ • SQLite        │
│ • Historical    │    │ • Health        │    │ • Backups       │
└─────────────────┘    └─────────────────┘    └─────────────────┘
```

## Example Strategies

### Moving Average Crossover
```python
from src.strategies.base_strategy import BaseStrategy

class MovingAverageStrategy(BaseStrategy):
    def analyze(self, data):
        short_ma = self.calculate_sma(data, self.short_period)
        long_ma = self.calculate_sma(data, self.long_period)
        
        if short_ma > long_ma:
            return self.create_signal("BUY", confidence=0.8)
        elif short_ma < long_ma:
            return self.create_signal("SELL", confidence=0.8)
        
        return self.create_signal("HOLD")
```

### RSI Mean Reversion
```python
class RSIStrategy(BaseStrategy):
    def analyze(self, data):
        rsi = self.calculate_rsi(data, self.rsi_period)
        
        if rsi < self.oversold_threshold:
            return self.create_signal("BUY", confidence=0.9)
        elif rsi > self.overbought_threshold:
            return self.create_signal("SELL", confidence=0.9)
        
        return self.create_signal("HOLD")
```

## Configuration Examples

### Development Configuration
```yaml
environment: "development"
exchanges:
  binance:
    sandbox: true  # Use testnet
risk_management:
  max_portfolio_risk: 0.001  # Very conservative
monitoring:
  alerting:
    enabled: false  # No alerts in dev
```

### Production Configuration
```yaml
environment: "production"
exchanges:
  binance:
    sandbox: false  # Live trading
risk_management:
  max_portfolio_risk: 0.01  # 1% risk per trade
monitoring:
  alerting:
    enabled: true
    channels: ["email", "slack"]
```

## Monitoring Dashboard

The bot includes comprehensive monitoring:

- **Portfolio Performance**: Real-time P&L tracking
- **Strategy Metrics**: Individual strategy performance
- **Risk Monitoring**: Drawdown and exposure tracking
- **System Health**: Exchange connectivity and error rates

Access the dashboard at `http://localhost:8000` after starting the bot.

## Safety Features

### Paper Trading Mode
Always test strategies in paper trading mode first:
```bash
python main.py --paper-trading
```

### Circuit Breakers
Automatic trading halts on:
- Daily loss exceeding threshold
- Maximum drawdown reached
- Excessive strategy errors
- Exchange connectivity issues

### Risk Controls
- **Position Sizing**: Automatic calculation based on risk tolerance
- **Stop Losses**: Configurable stop loss and trailing stops
- **Portfolio Limits**: Maximum positions and exposure limits
- **Correlation Limits**: Prevent over-concentration in correlated assets

## Getting Help

### Documentation
- **[User Guide](USER_GUIDE.md)**: Complete operation manual
- **[API Reference](API_REFERENCE.md)**: Technical API documentation
- **[Strategy Guide](STRATEGY_DEVELOPMENT_GUIDE.md)**: Custom strategy development

### Support Channels
- **GitHub Issues**: Bug reports and feature requests
- **Documentation**: Comprehensive guides and examples
- **Community**: Join discussions and share experiences

### Troubleshooting
Common issues and solutions:

1. **Bot won't start**: Check configuration and API keys
2. **No signals**: Verify strategy parameters and market data
3. **Connection errors**: Test exchange connectivity
4. **High memory usage**: Adjust data retention settings

See the [User Guide](USER_GUIDE.md) for detailed troubleshooting.

## Contributing

We welcome contributions! Please see:
- **Code Style**: Follow PEP 8 guidelines
- **Testing**: Add tests for new features
- **Documentation**: Update docs for changes
- **Issues**: Use GitHub issues for bugs and features

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Disclaimer

**Trading involves risk of loss. This software is provided as-is without warranty. Always test thoroughly before live trading and never risk more than you can afford to lose.**

---

## Quick Links

| Resource | Description |
|----------|-------------|
| [User Guide](USER_GUIDE.md) | Complete operation manual |
| [API Reference](API_REFERENCE.md) | Technical documentation |
| [Unified Configuration Guide](UNIFIED_CONFIGURATION_GUIDE.md) | New configuration system (v1.1.28+) |
| [Configuration](CONFIGURATION.md) | Configuration reference |
| [Configuration Migration Guide](CONFIGURATION_MIGRATION_GUIDE.md) | Migration from older versions |
| [Configuration Troubleshooting](CONFIGURATION_TROUBLESHOOTING_GUIDE.md) | Configuration issue resolution |
| [Deployment](DEPLOYMENT_GUIDE.md) | Deployment instructions |
| [Strategy Development](STRATEGY_DEVELOPMENT_GUIDE.md) | Custom strategies |
| [Examples](../examples/) | Code examples and templates |

**Happy Trading! 🚀**
